(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "typedoc", "typedoc/dist/lib/converter", "./renameNavLabelPlugin", "./renameExternalModulePlugin"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const typedoc_1 = require("typedoc");
    const converter_1 = require("typedoc/dist/lib/converter");
    const renameNavLabelPlugin = require("./renameNavLabelPlugin");
    const renameExternalModulePlugin = require("./renameExternalModulePlugin");
    function load({ application }) {
        // Remove all References
        application.converter.on(converter_1.Converter.EVENT_RESOLVE_BEGIN, context => {
            for (const reflection of context.project.getReflectionsByKind(typedoc_1.ReflectionKind.Reference)) {
                context.project.removeReflection(reflection);
            }
        });
        /**
         * used like so:
         * --navigation-label-globals "ui-router-ng2"
         * or
         * -nlg ui-router-ng2
         */
        application.options.addDeclaration({ name: 'navigation-label-globals', short: 'nlg' });
        /**
         * used like so:
         * --navigation-label-externals "UI-Router Internal API"
         * or
         * -nle "UI-Router Internal API"
         */
        application.options.addDeclaration({ name: 'navigation-label-externals', short: 'nle' });
        /**
         * -nli "Public API"
         */
        application.options.addDeclaration({ name: 'navigation-label-internals', short: 'nli' });
        application.renderer.addComponent('RenameNavLabel', renameNavLabelPlugin.RenameNavLabelPlugin);
        application.converter.addComponent('RenameExtModule', renameExternalModulePlugin.RenameExternalModulePlugin);
    }
    exports.load = load;
});
